# display, extcon, power, usb are always enabled

#Just For debugging
%define sdb_prestart off

Name:       deviced
Summary:    Deviced
Version:    10.0.0
Release:    1
Group:      System/Management
License:    Apache-2.0
Source0:    %{name}-%{version}.tar.gz
Source1:    deviced.manifest
Source2:    libdeviced.manifest

BuildRequires:  cmake
BuildRequires:  libattr-devel
BuildRequires:  gettext-devel
BuildRequires:  pkgconfig(mount)
BuildRequires:  pkgconfig(vconf)
BuildRequires:  pkgconfig(dlog)
BuildRequires:  pkgconfig(capi-base-common)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(eventsystem)
BuildRequires:  pkgconfig(libtzplatform-config)
BuildRequires:  pkgconfig(hwcommon)
BuildRequires:  pkgconfig(capi-system-info)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libinput)
BuildRequires:	pkgconfig(capi-system-sensor)
BuildRequires:	pkgconfig(fuse)
BuildRequires:	pkgconfig(minizip)
BuildRequires:	pkgconfig(libkmod)
BuildRequires:	pkgconfig(libusbgx)
BuildRequires:	pkgconfig(libsyscommon)
BuildRequires:	pkgconfig(capi-system-device)
BuildRequires:	pkgconfig(wayland-client)
BuildRequires:	pkgconfig(tizen-extension-client)
BuildRequires:	pkgconfig(tizen-dpms-client)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(argos_watchdog)

Requires: %{name}-tools = %{version}-%{release}
%{?systemd_requires}
Requires(post): /usr/bin/vconftool
Requires(post): %{_sbindir}/update-alternatives
Requires(preun): %{_sbindir}/update-alternatives

%description
Deviced

%package -n libdeviced
Summary:    Deviced library
Group:      Development/Libraries
Requires:   %{name} = %{version}-%{release}

%description -n libdeviced
Deviced library for device control.
Libdeviced is profile-independent; i.e., every profile has the same
binary for libdeviced.

%package -n libdeviced-devel
Summary:    Deviced library for (devel)
Group:      Development/Libraries
Requires:   libdeviced = %{version}-%{release}

%description -n libdeviced-devel
Deviced library for device control (devel).
Because this is internal interface, every profile MUST have the same
devel package.

%package tools
Summary:    Deviced tools
Group:      System/Utilities

%description tools
Deviced helper programs.
Deviced-tools is profile-independent; i.e., every profile has the same
binary for deviced-tools.

%package auto-test
Summary:    Deviced auto test tool
Group:      System/Utilities

%description auto-test
Deviced helper programs.
This package can be installed optional for auto dbus test.

%package plugin-profile-mobile
Summary:    Plugin libraries for mobile devices
Group:      System/Management
Requires:   %{name} = %{version}-%{release}

%description plugin-profile-mobile
Plugin libraries for mobile devices

%package plugin-profile-wearable
Summary:    Plugin libraries for wearable devices
Group:      System/Management
Requires:   %{name} = %{version}-%{release}

%description plugin-profile-wearable
Plugin libraries for wearable devices

%package plugin-profile-tv
Summary:    Plugin libraries for TV devices
Group:      System/Management
Requires:   %{name} = %{version}-%{release}

%description plugin-profile-tv
Plugin libraries for TV devices

%package plugin-profile-iot
Summary:    Plugin libraries for IoT devices
Group:      System/Management
Requires:   %{name} = %{version}-%{release}

%description plugin-profile-iot
Plugin libraries for IoT devices

%prep
%setup -q

%ifarch %{arm} aarch64
	%define ARCH arm
%endif

%ifarch %{arm} %ix86
	%define ARCH_BIT 32
%else
	%define ARCH_BIT 64
%endif

%if 0%{?tizen_build_devel_mode} == 1
%define engineer_mode on
%else
%define engineer_mode off
%endif

%define battery_module on

%cmake \
	-DTZ_SYS_ETC=%TZ_SYS_ETC \
	-DCMAKE_INSTALL_PREFIX=%{_prefix} \
	-DARCH=%{ARCH} \
	-DARCH_BIT=%{ARCH_BIT} \
	-DDPMS=%{DPMS} \
	-DENGINEER_MODE=%{engineer_mode} \
	-DBATTERY_MODULE=%{battery_module} \
	-DDISPLAY_MODULE=on \
	-DEXTCON_MODULE=on \
	-DIR_MODULE=on \
	-DLED_MODULE=on \
	-DPOWER_MODULE=on \
	-DSDB_PRESTART=%{sdb_prestart} \
	-DTOUCHSCREEN_MODULE=on \
	-DTZIP_MODULE=on \
	-DUSB_MODULE=on \
	-DUSBHOST_MODULE=on \
	-DTHERMAL_MODULE=on \
	-DTIZEN_FEATURE_CPU_MODULE=on \
	-DTIZEN_FEATURE_USBHOST_TEST=on \
	-DTOUCH_SENSITIVITY_MODULE=on \
	-DDUMP_MODULE=on \
	-DDEVICE_BOARD_MODULE=on \
	#eol

%build
cp %{SOURCE1} .
cp %{SOURCE2} .

make %{?jobs:-j%jobs}

%install
rm -rf %{buildroot}
%make_install

%install_service multi-user.target.wants deviced.service
# usb_module condition is removed because it is always on
%if %{?sdb_prestart} == on
%install_service basic.target.wants sdb-prestart.service
%endif

mkdir -p %{buildroot}%{TZ_SYS_DUMPGEN}
install -m 775 scripts/dump_pmstate_log.sh %{buildroot}%{TZ_SYS_DUMPGEN}/dump_pmstate_log.sh

%post
# Assume power module is on (-DPOWER_MODULE=on)
update-alternatives --install %{_prefix}/lib/systemd/systemd-shutdown systemd-shutdown %{_prefix}/lib/systemd/deviced-shutdown 500

#memory type vconf key init
users_gid=$(getent group %{TZ_SYS_USER_GROUP} | cut -f3 -d':')

systemctl daemon-reload
if [ "$1" == "1" ]; then
    systemctl restart deviced.service
fi

%preun
# Assume power module is on (-DPOWER_MODULE=on)
update-alternatives --remove systemd-shutdown %{_prefix}/lib/systemd/deviced-shutdown

%postun
systemctl daemon-reload
if [ "$1" == "0" ]; then
    systemctl stop deviced.service
fi

%post -n libdeviced -p /sbin/ldconfig

%postun -n libdeviced -p /sbin/ldconfig

%post plugin-profile-mobile
mv %{_sysconfdir}/deviced/mobile-display.conf %{_sysconfdir}/deviced/display.conf
mkdir -p %{_libdir}/deviced
mv %{_libdir}/mobile-display.so %{_libdir}/deviced/display.so
%if %{?battery_module} == on
mv %{_libdir}/mobile-battery.so %{_libdir}/deviced/battery.so
%endif

%post plugin-profile-wearable
mv %{_sysconfdir}/deviced/wearable-display.conf %{_sysconfdir}/deviced/display.conf
mkdir -p %{_libdir}/deviced
mv %{_libdir}/wearable-display.so %{_libdir}/deviced/display.so
%if %{?battery_module} == on
mv %{_libdir}/wearable-battery.so %{_libdir}/deviced/battery.so
%endif

%post plugin-profile-tv
mv %{_sysconfdir}/deviced/tv-display.conf %{_sysconfdir}/deviced/display.conf
mkdir -p %{_libdir}/deviced
mv %{_libdir}/tv-display.so %{_libdir}/deviced/display.so

%post plugin-profile-iot
mv %{_sysconfdir}/deviced/iot-display.conf %{_sysconfdir}/deviced/display.conf
mkdir -p %{_libdir}/deviced
mv %{_libdir}/iot-display.so %{_libdir}/deviced/display.so

%files
%manifest %{name}.manifest
%license LICENSE.Apache-2.0
%{_bindir}/deviced
%{_unitdir}/multi-user.target.wants/deviced.service
%{_unitdir}/deviced.service
%{_datadir}/dbus-1/system-services/org.tizen.system.deviced.service
%if %{?sdb_prestart} == on
%{_unitdir}/sdb-prestart.service
%{_unitdir}/basic.target.wants/sdb-prestart.service
%endif
%config %{_sysconfdir}/dbus-1/system.d/org.tizen.system.deviced.conf
%config %{_sysconfdir}/deviced/power.conf
%if %{?battery_module} == on
%config %{_sysconfdir}/deviced/battery.conf
%endif
# usbhost_test
%{_sysconfdir}/deviced/usb-host-test/test_gadget.gs
%{_bindir}/usb-host-ffs-test-daemon
%{_unitdir}/usb-host-ffs-test-daemon.service
%{_unitdir}/usb-host-test.socket
%{_sysconfdir}/deviced/usb-host-test/descs
%{_sysconfdir}/deviced/usb-host-test/strs

# Assume power module is on (-DPOWER_MODULE=on)
%{_prefix}/lib/systemd/deviced-shutdown

%files -n libdeviced
%manifest deviced.manifest
%license LICENSE.Apache-2.0
%defattr(-,root,root,-)
%{_libdir}/libdeviced.so.*

%files -n libdeviced-devel
%defattr(-,root,root,-)
%{_includedir}/deviced/*.h
%{_includedir}/deviced/core/*.h
%{_includedir}/deviced/shared/*.h
%{_includedir}/deviced/extcon/*.h
%{_libdir}/libdeviced.so
%{_libdir}/pkgconfig/deviced.pc

%files tools
%manifest deviced.manifest
%license LICENSE.Apache-2.0
%{_bindir}/devicectl
#if #{?usb_module} == on ==> always on
%{_bindir}/direct_set_debug.sh
%{TZ_SYS_DUMPGEN}/dump_pmstate_log.sh
#endif

%files auto-test
%manifest deviced.manifest
%license LICENSE.Apache-2.0
%{_bindir}/deviced-auto-test
%config %{_sysconfdir}/deviced/auto-test.conf

%files plugin-profile-mobile
%manifest deviced.manifest
%license LICENSE.Apache-2.0
%defattr(-,root,root,-)
%config %{_sysconfdir}/deviced/mobile-display.conf
%{_libdir}/mobile-display.so
%if %{?battery_module} == on
%{_libdir}/mobile-battery.so
%endif
%{_unitdir}/rndis.service
%{_bindir}/rndis.sh

%files plugin-profile-wearable
%manifest deviced.manifest
%license LICENSE.Apache-2.0
%defattr(-,root,root,-)
%config %{_sysconfdir}/deviced/wearable-display.conf
%{_libdir}/wearable-display.so
%if %{?battery_module} == on
%{_libdir}/wearable-battery.so
%endif
%{_unitdir}/rndis.service
%{_bindir}/rndis.sh

%files plugin-profile-tv
%manifest deviced.manifest
%license LICENSE.Apache-2.0
%defattr(-,root,root,-)
%config %{_sysconfdir}/deviced/tv-display.conf
%{_libdir}/tv-display.so
%{_unitdir}/rndis.service
%{_bindir}/rndis.sh

%files plugin-profile-iot
%manifest deviced.manifest
%license LICENSE.Apache-2.0
%defattr(-,root,root,-)
%config %{_sysconfdir}/deviced/iot-display.conf
%{_libdir}/iot-display.so
%{_unitdir}/rndis.service
%{_bindir}/rndis.sh
