/*
 * deviced
 *
 * Copyright (c) 2020 - 2021 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <time.h>
#include <glib.h>

#include "display/core.h"
#include "core/log.h"
#include "core/device-notifier.h"
#include "power-supply.h"
#include "battery-ops.h"
#include "battery.h"
#include "dd-display.h"

static struct battery_status *battery;

static int display_changed(void *data)
{
	static enum state_t old;
	static enum state_t state;

	if (!data)
		return state;

	old = state;
	state = *(int *)data;

	if (battery->health != HEALTH_LOW && battery->health != HEALTH_HIGH)
		return state;

	/* relaunch health popup on LCDON */
	if ((old == S_SLEEP || old == S_LCDOFF)
		&& (state == S_LCDDIM || state == S_NORMAL))
		relaunch_health_popup();

	return state;
}

static int check_power_supply_noti(void)
{
	int block;

	if (vconf_get_bool("db/setting/blockmode_wearable", &block) != 0)
		return 1;
	if (block == 0)
		return 1;
	return 0;
}

static void update_ovp(enum battery_noti_status status)
{
	static int old = DEVICE_NOTI_OFF;

	if (old == status)
		return;

	old = status;
	_I("Charge(%d) ovp(%d, old: %d) with lcd(%s)", battery->charge_now, battery->health,
		old_battery.health, (status == DEVICE_NOTI_ON) ? "dim" : "normal");

	old_battery.health = battery->health;
	device_notify(DEVICE_NOTIFIER_BATTERY_OVP, (void *)&battery->health);
	battery_pm_change_internal(INTERNAL_LOCK_POPUP, LCD_NORMAL);
}

static void battery_notification_init(void *data)
{
	struct battery_plugin *plugin = (struct battery_plugin *)data;

	if (!plugin)
		return;

	_D("Add plugins for battery notification.");
	plugin->check_power_supply_noti = check_power_supply_noti;
	plugin->update_ovp = update_ovp;
	plugin->display_changed = display_changed;

	register_notifier(DEVICE_NOTIFIER_LCD, display_changed);
}

static const struct battery_ops battery_notification_ops = {
	.name     = "battery_notification",
	.init     = battery_notification_init,
};

BATTERY_OPS_REGISTER(&battery_notification_ops)

static void __CONSTRUCTOR__ initialize(void)
{
	battery = get_var_battery_status();
	if (!battery)
		_E("Failed to get battery status structure.");
}
