/*
 * test
 *
 * Copyright (c) 2020 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#include "test.h"
#include <device/booting-internal.h>

#define METHOD_GET_REBOOT_MODE		"GetRebootMode"

static bool get_reboot_mode(void)
{
	int ret;

	ret = device_get_reboot_mode();

	return capi_reboot_result(METHOD_GET_REBOOT_MODE, ret);
}

static void booting_test_all(int *success, int *fail)
{
	int s = 0;
	int f = 0;

	(get_reboot_mode())		? s++ : f++;

	if (NULL != success)    *success = s;
	if (NULL != fail)       *fail = f;
}

static void booting_init(void *data)
{
	int success = 0;
	int fail = 0;

	_I("start test");

	booting_test_all(&success, &fail);

	_I("Total: %d, Success: %d, Fail: %d", success+fail, success, fail);
}

static void booting_exit(void *data)
{
	_I("end test");
}

static int booting_unit(int argc, char **argv)
{
	if (argc < 4) {
		int success = 0;
		int fail = 0;

		_I("start test");
		booting_test_all(&success, &fail);
		_I("Total: %d, Success: %d, Fail: %d", success+fail, success, fail);
	} else if (0 == strcasecmp(argv[3], METHOD_GET_REBOOT_MODE)) {
		get_reboot_mode();
	} else {
		_E("Unknown test case!!!");
	}

	return 0;
}

static const struct test_ops booting_test_ops = {
	.priority = TEST_PRIORITY_NORMAL,
	.name     = "booting",
	.init     = booting_init,
	.exit    = booting_exit,
	.unit    = booting_unit,
};

TEST_OPS_REGISTER(&booting_test_ops)
