/*
 * test
 *
 * Copyright (c) 2013 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#include "test.h"

#define METHOD_SYSNOTI_GETREVISION	"GetRevision"


static bool get_sysnoti_revision()
{
	GVariant *msg;
	int val;
	bool ret = FALSE;

	msg = dbus_handle_method_sync_with_reply_var(DEVICED_BUS_NAME,
					DEVICED_PATH_SYSNOTI,
					DEVICED_INTERFACE_SYSNOTI,
					METHOD_SYSNOTI_GETREVISION, NULL);
	if (!msg) {
		_E("fail : no reply");
		return ret;
	}

	if (!g_variant_get_safe(msg, "(i)", &val))
		_E("fail : no message");
	else {
		if ((val == -ENOTSUP) || (val == -ENOSYS)) {
			_I("Not supported feature! : %d", val);
			ret = TRUE;
		} else if (val < 0) {
			_E("fail : returned fail (%d)", val);
		} else {
			_I("success : %d", val);
			ret = TRUE;
		}
	}

	g_variant_unref(msg);
	return ret;
}

void proc_test_all(int *success, int *fail)
{
	int s = 0;
	int f = 0;

	(get_sysnoti_revision())	? s++ : f++;

	if (NULL != success)    *success = s;
	if (NULL != fail)       *fail = f;
}

static void proc_init(void *data)
{
	int success = 0;
	int fail = 0;

	_I("start test");

	proc_test_all(&success, &fail);

	_I("Total: %d, Success: %d, Fail: %d", success+fail, success, fail);
}

static void proc_exit(void *data)
{
	_I("end test");
}

static int proc_unit(int argc, char **argv)
{
	if (argc < 4) {
		int success = 0;
		int fail = 0;

		_I("start test");
		proc_test_all(&success, &fail);
		_I("Total: %d, Success: %d, Fail: %d", success+fail, success, fail);
	} else if (0 == strcmp(argv[3], METHOD_SYSNOTI_GETREVISION)) {
		get_sysnoti_revision();
	} else {
		_E("Unknown test case!!!");
	}

	return 0;
}

static const struct test_ops proc_test_ops = {
	.priority = TEST_PRIORITY_NORMAL,
	.name     = "proc",
	.init     = proc_init,
	.exit    = proc_exit,
	.unit    = proc_unit,
};

TEST_OPS_REGISTER(&proc_test_ops)
