/*
 * test
 *
 * Copyright (c) 2020 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#include "test.h"
#include <device/touchscreen-internal.h>

#define METHOD_TOUCHSCREEN_ENABLE  	"Enable"
#define METHOD_TOUCHSCREEN_DISABLE 	"Disable"

static bool touchscreen_disable(void)
{
	int ret;

	ret = device_touchscreen_disable(__cb);

	return capi_result(METHOD_TOUCHSCREEN_DISABLE, ret);
}

static bool touchscreen_enable(void)
{
	int ret;

	ret = device_touchscreen_enable(__cb);

	return capi_result(METHOD_TOUCHSCREEN_ENABLE, ret);
}

static void touchscreen_test_all(int *success, int *fail)
{
	int s = 0;
	int f = 0;

	(touchscreen_disable())		? s++ : f++;
	(touchscreen_enable())		? s++ : f++;

	if (NULL != success)		*success = s;
	if (NULL != fail)		*fail = f;
}

static void touchscreen_init(void *data)
{
	int success = 0;
	int fail = 0;

	_I("start test");

	touchscreen_test_all(&success, &fail);

	_I("Total: %d, Success: %d, Fail: %d", success+fail, success, fail);
}

static void touchscreen_exit(void *data)
{
	_I("end test");
}

static int touchscreen_unit(int argc, char **argv)
{
	if (argc < 4) {
		int success = 0;
		int fail = 0;

		_I("start test");
		touchscreen_test_all(&success, &fail);
		_I("Total: %d, Success: %d, Fail: %d", success+fail, success, fail);
	} else if (0 == strcasecmp(argv[3], METHOD_TOUCHSCREEN_ENABLE)) {
		touchscreen_enable();
	} else if (0 == strcasecmp(argv[3], METHOD_TOUCHSCREEN_DISABLE)) {
		touchscreen_disable();
	} else {
		_E("Unknown test case!!!");
	}

	return 0;
}

static const struct test_ops touchscreen_test_ops = {
	.priority = TEST_PRIORITY_NORMAL,
	.name     = "touchscreen",
	.init     = touchscreen_init,
	.exit     = touchscreen_exit,
	.unit     = touchscreen_unit,
};

TEST_OPS_REGISTER(&touchscreen_test_ops)
