/*
 * deviced
 *
 * Copyright (c) 2020 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * @file	display-lock.h
 * @brief	Manage each state's lock. Lock blocks state transition by timeout.
 *
 */
#ifndef __DISPLAY_LOCK_H__
#define __DISPLAY_LOCK_H__

#include "core.h"

typedef struct _pm_lock_node {
	enum state_t state;
	pid_t pid;
	guint timeout_id;
	guint warning_id;
	GVariant *warning_param;
	time_t time;
	bool holdkey_block;
	bool background;
	bool broadcast_warning;

	/* Set true when the lock holder is an entry of
	 * the list display_lock_killable_daemon.
	 * If true, deviced tries to kill this lock holder when
	 * the holder holds lock longer than KILLABLE_DAEMON_LOCK_LIMIT */
	bool killable_daemon;

	/* Set true when the lock holder holds lock
	 * longer than KILLABLE_DAEMON_LOCK_LIMIT.
	 * After a while, FORCE_RELEASE_LOCK_INTERVAL,
	 * this lock will be released. */
	bool force_release;
} PmLockNode;

bool check_lock_state(int state);
PmLockNode *find_node(enum state_t s_index, pid_t pid);
PmLockNode *add_node(enum state_t s_index, pid_t pid, guint timeout_id, bool holdkey_block);
int del_node(enum state_t s_index, PmLockNode *n);
int check_lock_condition(enum state_t state);
int check_holdkey_block(enum state_t state);
int delete_condition(enum state_t state);
void print_node(int next);
void makeup_trans_condition(void);
int check_processes(enum state_t prohibit_state);
int get_trans_condition(void);
dd_list *get_cond_head(enum state_t s_index);
int process_background(void *data);
int process_foreground(void *data);
void update_lock_timer(PMMsg *data, PmLockNode *node, guint timeout_id);

extern int custom_holdkey_block;

#endif /* __DISPLAY_LOCK_H__ */
