/*
 * deviced
 *
 * Copyright (c) 2020 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef __DISPLAY_SIGNAL_H__
#define __DISPLAY_SIGNAL_H__

#include <time.h>
#include <libsyscommon/dbus-system.h>

#include "util.h"
#include "core/devices.h"
#include "core/device-notifier.h"

static inline long clock_gettime_to_long(void)
{
	struct timespec now;
	int ret;

	ret = clock_gettime(CLOCK_REALTIME, &now);

	if (ret < 0) {
		_E("Failed to clock gettime!");
		return 0;
	}

	return SEC_TO_MSEC(now.tv_sec) + NSEC_TO_MSEC(now.tv_nsec);
}

#define PM_WAKEUP		0
#define PM_SUSPEND		1

enum signal_type {
	SIGNAL_INVALID = 0,
	SIGNAL_PRE,
	SIGNAL_POST,
	SIGNAL_MAX,
};

void broadcast_pm_suspend(void);
void broadcast_pm_wakeup(void);
void broadcast_lcd_on(enum signal_type type, enum device_flags flags);
void broadcast_lcd_off(enum signal_type type, enum device_flags flags);
void broadcast_lcd_off_late(enum device_flags flags);
void set_process_active(bool flag, pid_t pid);

#endif /* __DISPLAY_SIGNAL_H__ */
