/*
 * deviced
 *
 * Copyright (c) 2014 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#include <stdio.h>
#include <vconf.h>
#include <bundle.h>
#include <eventsystem.h>

#include "core/log.h"
#include "display/poll.h"
#include "display/display-ops.h"
#include "extcon/extcon.h"
#include "shared/plugin.h"

#define SIGNAL_EARJACK_STATE	"ChangedEarjack"
#define GET_EARJACK_STATE	"Earjack"

static struct display_plugin *disp_plgn;
static void earjack_send_broadcast(int status)
{
	static int old = 0;
	int ret;

	if (old == status)
		return;

	_I("Broadcast earjack status(%d).", status);
	old = status;

	ret = dbus_handle_emit_dbus_signal(NULL,
						DEVICED_PATH_SYSNOTI,
						DEVICED_INTERFACE_SYSNOTI,
						SIGNAL_EARJACK_STATE,
						g_variant_new("(i)", status));
	if (ret < 0)
		_E("Failed to send dbus signal(%s)", SIGNAL_EARJACK_STATE);
}

static void earjack_send_system_event(int status)
{
	bundle *b;
	const char *str;

	if (status)
		str = EVT_VAL_EARJACK_CONNECTED;
	else
		str = EVT_VAL_EARJACK_DISCONNECTED;

	b = bundle_create();
	bundle_add_str(b, EVT_KEY_EARJACK_STATUS, str);
	eventsystem_send_system_event(SYS_EVENT_EARJACK_STATUS, b);
	bundle_free(b);
}

static int earjack_update(const char *index, int status)
{
	int ret;

	_I("Earjack changed. status=%d", status);
	ret = vconf_set_int(VCONFKEY_SYSMAN_EARJACK, status);
	if (ret < 0)
		_E("Failed to set vconf value for earjack: %d", vconf_get_ext_errno());
	earjack_send_broadcast(status);
	earjack_send_system_event(status);
	if (status != EARJACK_DICONNECTED) {
		if (disp_plgn->pm_change_internal)
			disp_plgn->pm_change_internal(INTERNAL_LOCK_EARJACK, LCD_NORMAL);

		extcon_update_count(EXTCON_EARJACK, 1);
	}

	return 0;
}

static struct extcon_ops earjack_extcon_ops = {
	.name   = EXTCON_CABLE_HEADPHONE_OUT,
	.update = earjack_update,
};

EXTCON_OPS_REGISTER(earjack_extcon_ops)

static void __CONSTRUCTOR__ initialize(void)
{
	disp_plgn = get_var_display_plugin();
	if (!disp_plgn)
		_E("Failed to get display plugin variable.");
}
