/*
 * deviced
 *
 * Copyright (c) 2020 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef __POWER_CONTROL_H__
#define __POWER_CONTROL_H__

#include "display/core.h"


#define POWER_AUTOSLEEP_PATH    "/sys/power/autosleep"
#define POWER_LOCK_PATH         "/sys/power/wake_lock"
#define POWER_UNLOCK_PATH       "/sys/power/wake_unlock"
#define POWER_WAKEUP_PATH       "/sys/power/wakeup_count"
#define POWER_STATE_PATH        "/sys/power/state"

#define FREEZER_VITAL_WAKEUP_CGROUP "/sys/fs/cgroup/freezer/vital_wakeup/freezer.state"

#define SET_SUSPEND_TIME		0.5

enum mainlock_state {
	POWER_UNLOCK = 0,
	POWER_LOCK,
};

/*
 * Vital state enumeration
 */
enum vital_state {
	VITAL_SLEEP,	/* suspend state */
	VITAL_WAKEUP,	/* resume state */
	VITAL_DISPLAY_WAKEUP,
	VITAL_EXIT,
};

#ifdef ENABLE_PM_LOG
void pm_history_init(void);
void pm_history_save(enum pm_log_type log_type, int code);
void pm_history_print(int fd, int count);
#endif
bool vital_mode(void);
int vital_state_changed(void *data);
int pm_suspend(void);
int pm_enable_autosleep(void);
int pm_power_lock(void);
int pm_power_unlock(void);
int pm_get_power_lock(void);
int pm_get_power_lock_support(void);
int check_wakeup_src(void);
int get_wakeup_count(int *cnt);
int set_wakeup_count(int cnt);
int suspend_other_process(int type);
#endif /* __POWER_CONTROL_H__ */
